@@ -1,5 +1,3 @@
-from __future__ import annotations
-
 import argparse
 import json
 import logging
@@ -14,10 +12,10 @@ logger = logging.getLogger(__name__)
 
 
 class PutExternalLinkageInfo:
-    def __init__(self, annowork_service: AnnoworkResource):
+    def __init__(self, annowork_service: AnnoworkResource):  # noqa: ANN204
         self.annowork_service = annowork_service
 
-    def main(self, user_id: str, external_linkage_info: dict[str, Any]):
+    def main(self, user_id: str, external_linkage_info: dict[str, Any]):  # noqa: ANN201
         old_info = self.annowork_service.wrapper.get_account_external_linkage_info_or_none(user_id)
         if old_info is None:
             logger.warning(f"user_id={user_id} のアカウント外部連携情報は存在しません。")
@@ -32,15 +30,13 @@ class PutExternalLinkageInfo:
         logger.info(f"{user_id=} のユーザの外部連携情報を設定しました。")
 
 
-def main(args):
+def main(args):  # noqa: ANN001, ANN201
     annowork_service = build_annoworkapi(args)
     external_linkage_info = get_json_from_args(args.external_linkage_info)
-    PutExternalLinkageInfo(annowork_service=annowork_service).main(
-        user_id=args.user_id, external_linkage_info=external_linkage_info
-    )
+    PutExternalLinkageInfo(annowork_service=annowork_service).main(user_id=args.user_id, external_linkage_info=external_linkage_info)
 
 
-def parse_args(parser: argparse.ArgumentParser):
+def parse_args(parser: argparse.ArgumentParser):  # noqa: ANN201
     parser.add_argument(
         "-u",
         "--user_id",
@@ -49,7 +45,7 @@ def parse_args(parser: argparse.ArgumentParser):
         help="登録対象ユーザのuser_id",
     )
 
-    SAMPLE_EXTERNAL_LINKAGE_INFO = {"annofab": {"account_id": "xxx"}}
+    SAMPLE_EXTERNAL_LINKAGE_INFO = {"annofab": {"account_id": "xxx"}}  # noqa: N806
 
     parser.add_argument(
         "--external_linkage_info",
@@ -65,8 +61,6 @@ def add_parser(subparsers: Optional[argparse._SubParsersAction] = None) -> argpa
     subcommand_name = "put_external_linkage_info"
     subcommand_help = "アカウント外部連携情報取得を更新します。"
 
-    parser = annoworkcli.common.cli.add_parser(
-        subparsers, subcommand_name, subcommand_help, description=subcommand_help
-    )
+    parser = annoworkcli.common.cli.add_parser(subparsers, subcommand_name, subcommand_help, description=subcommand_help)
     parse_args(parser)
     return parser
