@@ -1,5 +1,3 @@
-from __future__ import annotations
-
 import argparse
 import logging
 import multiprocessing
@@ -38,7 +36,7 @@ def get_annofab_project_ids(job_list: list[dict[str, Any]]) -> set[str]:
 
 
 class ListJobWithAnnofabProject:
-    def __init__(
+    def __init__(  # noqa: ANN204
         self,
         *,
         annowork_service: AnnoworkResource,
@@ -82,7 +80,7 @@ class ListJobWithAnnofabProject:
         job_id_list: Optional[list[str]] = None,
         parent_job_id_list: Optional[list[str]] = None,
         annofab_project_id_list: Optional[list[str]] = None,
-        is_show_parent_job: bool = False,
+        is_show_parent_job: bool = False,  # noqa: FBT001, FBT002
     ) -> list[dict[str, Any]]:
         job_list = self.list_job_obj.get_job_list(
             job_id_list=job_id_list,
@@ -115,9 +113,7 @@ class ListJobWithAnnofabProject:
 
             af_project = af_project_dict.get(af_project_id)
             if af_project is None:
-                logger.warning(
-                    f"annofab_project_id='{af_project_id}' のAnnofabプロジェクトを取得できませんでした。:: job_id={job['job_id']}"
-                )
+                logger.warning(f"annofab_project_id='{af_project_id}' のAnnofabプロジェクトを取得できませんでした。:: job_id={job['job_id']}")
                 job["annofab"] = None
                 continue
 
@@ -130,7 +126,7 @@ class ListJobWithAnnofabProject:
         return job_list
 
 
-def main(args):
+def main(args):  # noqa: ANN001, ANN201
     annowork_service = build_annoworkapi(args)
     job_id_list = get_list_from_args(args.job_id)
     parent_job_id_list = get_list_from_args(args.parent_job_id)
@@ -139,7 +135,11 @@ def main(args):
     main_obj = ListJobWithAnnofabProject(
         annowork_service=annowork_service,
         workspace_id=args.workspace_id,
-        annofab_service=build_annofabapi_resource_and_login(mfa_code=args.annofab_mfa_code),
+        annofab_service=build_annofabapi_resource_and_login(
+            annofab_login_user_id=args.annofab_user_id,
+            annofab_login_password=args.annofab_password,
+            mfa_code=args.annofab_mfa_code,
+        ),
         parallelism=args.parallelism,
     )
     job_list = main_obj.get_job_list_added_annofab_project(
@@ -150,7 +150,7 @@ def main(args):
     )
 
     if len(job_list) == 0:
-        logger.warning(f"ジョブの一覧が0件なので、出力しません。")
+        logger.warning("ジョブの一覧が0件なので、出力しません。")
         return
 
     logger.info(f"{len(job_list)} 件のジョブの一覧を出力します。")
@@ -162,7 +162,7 @@ def main(args):
         print_csv(df, output=args.output)
 
 
-def parse_args(parser: argparse.ArgumentParser):
+def parse_args(parser: argparse.ArgumentParser):  # noqa: ANN201
     parser.add_argument(
         "-w",
         "--workspace_id",
@@ -205,13 +205,13 @@ def parse_args(parser: argparse.ArgumentParser):
 
     parser.add_argument("-o", "--output", type=Path, help="出力先")
 
-    parser.add_argument(
-        "-f", "--format", type=str, choices=[e.value for e in OutputFormat], help="出力先", default=OutputFormat.CSV.value
-    )
+    parser.add_argument("-f", "--format", type=str, choices=[e.value for e in OutputFormat], help="出力先", default=OutputFormat.CSV.value)
 
     parser.add_argument("--parallelism", type=int, required=False, help="並列度。指定しない場合は、逐次的に処理します。")
 
     parser.add_argument("--annofab_mfa_code", type=str, help="Annofabにログインする際のMFAコード")
+    parser.add_argument("--annofab_user_id", type=str, help="Annofabにログインする際のユーザID")
+    parser.add_argument("--annofab_password", type=str, help="Annofabにログインする際のパスワード")
     parser.set_defaults(subcommand_func=main)
 
 
@@ -219,8 +219,6 @@ def add_parser(subparsers: Optional[argparse._SubParsersAction] = None) -> argpa
     subcommand_name = "list_job"
     subcommand_help = "ジョブとジョブに紐づくAnnofabプロジェクトの情報を一緒に出力します。"
 
-    parser = annoworkcli.common.cli.add_parser(
-        subparsers, subcommand_name, subcommand_help, description=subcommand_help
-    )
+    parser = annoworkcli.common.cli.add_parser(subparsers, subcommand_name, subcommand_help, description=subcommand_help)
     parse_args(parser)
     return parser
