@@ -1,12 +1,11 @@
-from __future__ import annotations
-
 import argparse
 import functools
 import itertools
 import logging
 import multiprocessing
+from collections.abc import Collection
 from pathlib import Path
-from typing import Any, Collection, Optional
+from typing import Any, Optional
 
 import pandas
 import requests
@@ -46,27 +45,21 @@ def _get_df_working_hours_from_df(
         df_af_working_hours: Annofabの作業時間情報
     """
     # annowork側の作業時間情報
-    df_aw_working_hours = df_actual_working_hours.merge(
-        df_user_and_af_account[["user_id", "annofab_account_id"]], how="left", on="user_id"
-    ).merge(
+    df_aw_working_hours = df_actual_working_hours.merge(df_user_and_af_account[["user_id", "annofab_account_id"]], how="left", on="user_id").merge(
         df_job_and_af_project[["job_id", "annofab_project_id"]],
         how="left",
         on="job_id",
     )
 
-    df_merged = df_aw_working_hours.merge(
-        df_af_working_hours, how="outer", on=["date", "annofab_project_id", "annofab_account_id"]
-    )
+    df_merged = df_aw_working_hours.merge(df_af_working_hours, how="outer", on=["date", "annofab_project_id", "annofab_account_id"])
 
-    TMP_SUFFIX = "_tmp"
+    TMP_SUFFIX = "_tmp"  # noqa: N806
     # df_merged は outer joinしているため、左側にも欠損値ができる。
     # それを埋めるために、以前に user情報, job情報の一意な dataframe を生成して、欠損値を埋める
-    USER_COLUMNS = ["workspace_member_id", "user_id", "username"]
-    df_merged = df_merged.merge(
-        df_user_and_af_account, how="left", on="annofab_account_id", suffixes=(None, TMP_SUFFIX)
-    )
+    USER_COLUMNS = ["workspace_member_id", "user_id", "username"]  # noqa: N806
+    df_merged = df_merged.merge(df_user_and_af_account, how="left", on="annofab_account_id", suffixes=(None, TMP_SUFFIX))
     for user_column in USER_COLUMNS:
-        df_merged[user_column].fillna(df_merged[f"{user_column}{TMP_SUFFIX}"], inplace=True)
+        df_merged[user_column] = df_merged[user_column].fillna(df_merged[f"{user_column}{TMP_SUFFIX}"])
 
     # job_id, job_nameの欠損値を、df_job_and_af_project を使って埋める
     # af_projectに紐付いているジョブとaf_projectのDataFrameを生成して、それを使って欠損値を埋める
@@ -80,14 +73,13 @@ def _get_df_working_hours_from_df(
         on=["annofab_project_id"],
         suffixes=(None, TMP_SUFFIX),
     )
-    df_merged["job_id"].fillna(df_merged[f"job_id{TMP_SUFFIX}"], inplace=True)
-    df_merged["job_name"].fillna(df_merged[f"job_name{TMP_SUFFIX}"], inplace=True)
+    df_merged["job_id"] = df_merged["job_id"].fillna(df_merged[f"job_id{TMP_SUFFIX}"])
+    df_merged["job_name"] = df_merged["job_name"].fillna(df_merged[f"job_name{TMP_SUFFIX}"])
 
     # annofab_project_titleを結合するために、annofab_projectだけのDataFrameを生成する
-    df_af_project = df_job_and_af_project.drop_duplicates(subset=["annofab_project_id"])[
-        ["annofab_project_id", "annofab_project_title"]
-    ]
+    df_af_project = df_job_and_af_project.drop_duplicates(subset=["annofab_project_id"])[["annofab_project_id", "annofab_project_title"]]
     df_merged = df_merged.merge(df_af_project, on="annofab_project_id", how="left")
+
     df_merged.fillna(
         {
             "actual_working_hours": 0,
@@ -97,9 +89,11 @@ def _get_df_working_hours_from_df(
     )
 
     return df_merged[
-        ["date", "job_id", "job_name"]
-        + USER_COLUMNS
-        + [
+        [
+            "date",
+            "job_id",
+            "job_name",
+            *USER_COLUMNS,
             "actual_working_hours",
             "annofab_project_id",
             "annofab_project_title",
@@ -111,7 +105,7 @@ def _get_df_working_hours_from_df(
 
 
 class ListWorkingHoursWithAnnofab:
-    def __init__(
+    def __init__(  # noqa: ANN204
         self,
         *,
         annowork_service: AnnoworkResource,
@@ -129,9 +123,7 @@ class ListWorkingHoursWithAnnofab:
             self.workspace_id, query_params={"includes_inactive_members": True}
         )
 
-        self.list_actual_working_time_obj = ListActualWorkingTime(
-            annowork_service, workspace_id, timezone_offset_hours=TIMEZONE_OFFSET_HOURS
-        )
+        self.list_actual_working_time_obj = ListActualWorkingTime(annowork_service, workspace_id, timezone_offset_hours=TIMEZONE_OFFSET_HOURS)
 
     def get_actual_working_hours_daily(
         self,
@@ -152,9 +144,7 @@ class ListWorkingHoursWithAnnofab:
         )
         self.list_actual_working_time_obj.set_additional_info_to_actual_working_time(actual_working_time_list)
 
-        result = create_actual_working_hours_daily_list(
-            actual_working_time_list, timezone_offset_hours=TIMEZONE_OFFSET_HOURS
-        )
+        result = create_actual_working_hours_daily_list(actual_working_time_list, timezone_offset_hours=TIMEZONE_OFFSET_HOURS)
         result = filter_actual_daily_list(result, start_date=start_date, end_date=end_date)
         return result
 
@@ -204,24 +194,16 @@ class ListWorkingHoursWithAnnofab:
         df_job = pandas.DataFrame(self.all_jobs)
 
         df_af_project = pandas.DataFrame({"job_id": list(job_ids)})
-        df_af_project["annofab_project_id"] = df_af_project["job_id"].apply(
-            lambda e: get_annofab_project_id_from_job(all_job_dict[e])
-        )
+        df_af_project["annofab_project_id"] = df_af_project["job_id"].apply(lambda e: get_annofab_project_id_from_job(all_job_dict[e]))
         df_af_project["annofab_project_title"] = df_af_project["annofab_project_id"].apply(get_project_title)
 
         df = df_job.merge(df_af_project, how="inner", on="job_id")
         return df[["job_id", "job_name", "annofab_project_id", "annofab_project_title"]]
 
-    def _get_af_working_hours_from_af_project(
-        self, af_project_id: str, start_date: Optional[str], end_date: Optional[str]
-    ) -> list[dict[str, Any]]:
+    def _get_af_working_hours_from_af_project(self, af_project_id: str, start_date: Optional[str], end_date: Optional[str]) -> list[dict[str, Any]]:
         try:
-            logger.debug(
-                f"annofab_project_id= '{af_project_id}' のAnnofabプロジェクトの作業時間を取得します。:: {start_date=}, {end_date=}"
-            )
-            account_statistics = self.annofab_service.wrapper.get_account_daily_statistics(
-                af_project_id, from_date=start_date, to_date=end_date
-            )
+            logger.debug(f"annofab_project_id= '{af_project_id}' のAnnofabプロジェクトの作業時間を取得します。:: {start_date=}, {end_date=}")
+            account_statistics = self.annofab_service.wrapper.get_account_daily_statistics(af_project_id, from_date=start_date, to_date=end_date)
         except requests.exceptions.HTTPError as e:
             if e.response.status_code == requests.codes.not_found:
                 logger.warning(f"annofab_project_id= '{af_project_id}' は存在しません。")
@@ -246,9 +228,7 @@ class ListWorkingHoursWithAnnofab:
                     )
         return result
 
-    def _get_af_working_hours(
-        self, af_project_ids: Collection[str], start_date: Optional[str], end_date: Optional[str]
-    ) -> pandas.DataFrame:
+    def _get_af_working_hours(self, af_project_ids: Collection[str], start_date: Optional[str], end_date: Optional[str]) -> pandas.DataFrame:
         """Annofabの作業時間情報が格納されたDataFrameを返す。
 
         返すDataFrameには以下の列が存在します。
@@ -273,13 +253,16 @@ class ListWorkingHoursWithAnnofab:
 
         else:
             for af_project_id in af_project_ids:
-                result.extend(
-                    self._get_af_working_hours_from_af_project(af_project_id, start_date=start_date, end_date=end_date)
-                )
+                result.extend(self._get_af_working_hours_from_af_project(af_project_id, start_date=start_date, end_date=end_date))
 
         if len(result) > 0:
             return pandas.DataFrame(result)
-        return pandas.DataFrame(columns=["date", "annofab_project_id", "annofab_account_id", "annofab_working_hours"])
+
+        df = pandas.DataFrame(columns=["date", "annofab_project_id", "annofab_account_id", "annofab_working_hours"])
+        # `astype()`を使用する理由：後続の処理で`fillna()`を実行した際に、「Downcasting object dtype arrays ～」というFutureWarningを発生させないようにするため  # noqa: E501
+        # https://qiita.com/yuji38kwmt/items/ba07a25924cfda363e42
+        df = df.astype({"annofab_working_hours": "float64"})
+        return df
 
     def _get_df_job_parent_job(self) -> pandas.DataFrame:
         """job_id, parent_job_id, parent_job_nameが格納されたpandas.DataFrameを返します。"""
@@ -289,15 +272,13 @@ class ListWorkingHoursWithAnnofab:
         df_job["parent_job_id"] = df_job["job_tree"].apply(get_parent_job_id_from_job_tree)
 
         df_parent_job = pandas.DataFrame({"parent_job_id": df_job["parent_job_id"].unique()})
-        df_parent_job["parent_job_name"] = df_parent_job["parent_job_id"].apply(
-            lambda e: all_job_dict[e]["job_name"] if e is not None else None
-        )
+        df_parent_job["parent_job_name"] = df_parent_job["parent_job_id"].apply(lambda e: all_job_dict[e]["job_name"] if e is not None else None)
 
         df = df_job.merge(df_parent_job, how="left", on="parent_job_id")
         return df[["job_id", "parent_job_id", "parent_job_name"]]
 
     @staticmethod
-    def _get_required_columns(is_show_parent_job: bool):
+    def _get_required_columns(is_show_parent_job: bool) -> list[str]:  # noqa: FBT001
         job_columns = [
             "job_id",
             "job_name",
@@ -314,11 +295,9 @@ class ListWorkingHoursWithAnnofab:
                 "parent_job_id",
                 "parent_job_name",
             ]
-            required_columns = (
-                ["date"] + job_columns + parent_job_columns + user_columns + ["actual_working_hours"] + annofab_columns
-            )
+            required_columns = ["date"] + job_columns + parent_job_columns + user_columns + ["actual_working_hours"] + annofab_columns  # noqa: RUF005
         else:
-            required_columns = ["date"] + job_columns + user_columns + ["actual_working_hours"] + annofab_columns
+            required_columns = ["date"] + job_columns + user_columns + ["actual_working_hours"] + annofab_columns  # noqa: RUF005
 
         required_columns.append("notes")
         return required_columns
@@ -332,6 +311,26 @@ class ListWorkingHoursWithAnnofab:
         user_ids: Optional[Collection[str]] = None,
         is_show_parent_job: bool = False,
     ) -> pandas.DataFrame:
+        def _get_af_project_ids(df: pandas.DataFrame) -> list[str]:
+            """
+            annoworkジョブとannofabプロジェクの情報が格納されたDataFrameから、アクセスできるAnnofabプロジェクトのIDのリストを返す。
+            Annofabプロジェクトにアクセスできるかは、`annofab_project_title`が空かどうかで判定します。
+
+            Args:
+                df: annoworkジョブとannofabプロジェクの情報が格納されたDataFrame。以下の列を参照します。
+                    * annofab_project_id
+                    * annofab_project_title
+
+
+            """
+            df = df.drop_duplicates(subset=["annofab_project_id", "annofab_project_title"])
+            # 補足：
+            #  * annofab_project_idがnaのとき：Annofabプロジェクトに紐付いていないジョブ
+            #  * annofab_project_titleがnaのとき：アクセスできないAnnofabプロジェクトに紐付いているジョブ
+            df = df[df["annofab_project_id"].notna() & df["annofab_project_title"].notna()]
+            # `unique()`を実行する理由：前述の`drop_duplicates`でannofab_project_idはユニークなはずだが、念の為`unique()`を実行した。
+            return list(df["annofab_project_id"].unique())
+
         def _get_start_date(df: pandas.DataFrame) -> Optional[str]:
             min_date = df["date"].min() if len(df) > 0 else None
             if start_date is None:
@@ -376,7 +375,7 @@ class ListWorkingHoursWithAnnofab:
             set(df_actual_working_hours["job_id"].unique()) | (set(job_ids) if job_ids is not None else set())
         )
 
-        af_project_ids = [e for e in df_job_and_af_project["annofab_project_id"].unique() if not pandas.isna(e)]
+        af_project_ids = _get_af_project_ids(df_job_and_af_project)
 
         df_af_working_hours = self._get_af_working_hours(
             af_project_ids=af_project_ids,
@@ -402,11 +401,7 @@ class ListWorkingHoursWithAnnofab:
         return df[required_columns]
 
     def get_job_id_list_from_parent_job_id_list(self, parent_job_id_list: Collection[str]) -> list[str]:
-        return [
-            e["job_id"]
-            for e in self.all_jobs
-            if get_parent_job_id_from_job_tree(e["job_tree"]) in set(parent_job_id_list)
-        ]
+        return [e["job_id"] for e in self.all_jobs if get_parent_job_id_from_job_tree(e["job_tree"]) in set(parent_job_id_list)]
 
     def get_job_id_list_from_annofab_project_id_list(self, annofab_project_id_list: list[str]) -> list[str]:
         annofab_project_id_set = set(annofab_project_id_list)
@@ -420,7 +415,7 @@ class ListWorkingHoursWithAnnofab:
         return [e["job_id"] for e in self.all_jobs if _match_job(e)]
 
 
-def main(args):
+def main(args):  # noqa: ANN001, ANN201
     job_id_list = get_list_from_args(args.job_id)
     parent_job_id_list = get_list_from_args(args.parent_job_id)
     annofab_project_id_list = get_list_from_args(args.annofab_project_id)
@@ -428,18 +423,20 @@ def main(args):
     start_date: Optional[str] = args.start_date
     end_date: Optional[str] = args.end_date
 
-    if all(
-        v is None
-        for v in [job_id_list, parent_job_id_list, annofab_project_id_list, user_id_list, start_date, end_date]
-    ):
+    if all(v is None for v in [job_id_list, parent_job_id_list, annofab_project_id_list, user_id_list, start_date, end_date]):
         logger.warning(
-            "'--start_date'や'--job_id'などの絞り込み条件が1つも指定されていません。" "WebAPIから取得するデータ量が多すぎて、WebAPIのリクエストが失敗するかもしれません。"
+            "'--start_date'や'--job_id'などの絞り込み条件が1つも指定されていません。"
+            "WebAPIから取得するデータ量が多すぎて、WebAPIのリクエストが失敗するかもしれません。"
         )
 
     main_obj = ListWorkingHoursWithAnnofab(
         annowork_service=build_annoworkapi(args),
         workspace_id=args.workspace_id,
-        annofab_service=build_annofabapi_resource_and_login(mfa_code=args.annofab_mfa_code),
+        annofab_service=build_annofabapi_resource_and_login(
+            annofab_login_user_id=args.annofab_user_id,
+            annofab_login_password=args.annofab_password,
+            mfa_code=args.annofab_mfa_code,
+        ),
         parallelism=args.parallelism,
     )
 
@@ -458,7 +455,7 @@ def main(args):
     )
 
     if len(df) == 0:
-        logger.warning(f"作業時間情報は0件なので、出力しません。")
+        logger.warning("作業時間情報は0件なので、出力しません。")
         return
 
     logger.info(f"{len(df)} 件の作業時間情報を出力します。")
@@ -469,7 +466,7 @@ def main(args):
         print_csv(df, output=args.output)
 
 
-def parse_args(parser: argparse.ArgumentParser):
+def parse_args(parser: argparse.ArgumentParser):  # noqa: ANN201
     parser.add_argument(
         "-w",
         "--workspace_id",
@@ -516,6 +513,9 @@ def parse_args(parser: argparse.ArgumentParser):
 
     parser.add_argument("--parallelism", type=int, required=False, help="並列度。指定しない場合は、逐次的に処理します。")
     parser.add_argument("--annofab_mfa_code", type=str, help="Annofabにログインする際のMFAコード")
+    parser.add_argument("--annofab_user_id", type=str, help="Annofabにログインする際のユーザID")
+    parser.add_argument("--annofab_password", type=str, help="Annofabにログインする際のパスワード")
+
     parser.set_defaults(subcommand_func=main)
 
 
@@ -523,8 +523,6 @@ def add_parser(subparsers: Optional[argparse._SubParsersAction] = None) -> argpa
     subcommand_name = "list_working_hours"
     subcommand_help = "日ごとの実績作業時間と、ジョブに紐づくAnnofabプロジェクトの作業時間を一緒に出力します。"
 
-    parser = annoworkcli.common.cli.add_parser(
-        subparsers, subcommand_name, subcommand_help, description=subcommand_help
-    )
+    parser = annoworkcli.common.cli.add_parser(subparsers, subcommand_name, subcommand_help, description=subcommand_help)
     parse_args(parser)
     return parser
