@@ -1,6 +1,5 @@
-from __future__ import annotations
-
 import argparse
+import copy
 import datetime
 import logging
 import subprocess
@@ -8,7 +7,7 @@ import tempfile
 from collections import defaultdict
 from dataclasses import dataclass
 from pathlib import Path
-from typing import Dict, Optional, Tuple
+from typing import Dict, Optional, Tuple  # noqa: UP035
 
 import pandas
 from annoworkapi.resource import Resource as AnnoworkResource
@@ -24,7 +23,7 @@ from annoworkcli.common.utils import print_csv
 logger = logging.getLogger(__name__)
 
 
-ActualWorkingHoursDict = Dict[Tuple[datetime.date, str, str], float]
+ActualWorkingHoursDict = Dict[Tuple[datetime.date, str, str], float]  # noqa: UP006
 """実績作業時間の日ごとの情報を格納する辞書
 key: (date, workspace_member_id, job_id), value: 実績作業時間
 """
@@ -40,13 +39,13 @@ class AnnofabLabor(DataClassJsonMixin):
     actual_worktime_hour: float
 
 
-JobIdAnnofabProjectIdDict = Dict[str, str]
+JobIdAnnofabProjectIdDict = Dict[str, str]  # noqa: UP006
 """key:job_id, value:annofab_project_idのdict
 """
 
 
 class ListLabor:
-    def __init__(self, annowork_service: AnnoworkResource, workspace_id: str):
+    def __init__(self, annowork_service: AnnoworkResource, workspace_id: str):  # noqa: ANN204
         self.annowork_service = annowork_service
         self.workspace_id = workspace_id
 
@@ -59,9 +58,7 @@ class ListLabor:
             timezone_offset_hours=TIMEZONE_OFFSET_HOURS,
         )
 
-    def get_job_id_annofab_project_id_dict_from_annofab_project_id(
-        self, annofab_project_id_list: list[str]
-    ) -> JobIdAnnofabProjectIdDict:
+    def get_job_id_annofab_project_id_dict_from_annofab_project_id(self, annofab_project_id_list: list[str]) -> JobIdAnnofabProjectIdDict:
         # オーダを減らすため、事前にdictを作成する
         annofab_project_id_dict: dict[str, list[str]] = defaultdict(list)
         for job in self.all_job_list:
@@ -73,7 +70,9 @@ class ListLabor:
         for annofab_project_id in annofab_project_id_list:
             job_id_list = annofab_project_id_dict.get(annofab_project_id)
             if job_id_list is None:
-                logger.warning(f"ジョブの外部連携情報に、AnnofabのプロジェクトID '{annofab_project_id}' を表すURLが設定されたジョブは見つかりませんでした。")
+                logger.warning(
+                    f"ジョブの外部連携情報に、AnnofabのプロジェクトID '{annofab_project_id}' を表すURLが設定されたジョブは見つかりませんでした。"
+                )
                 continue
 
             for job_id in job_id_list:
@@ -83,9 +82,7 @@ class ListLabor:
 
     def get_job_id_annofab_project_id_dict_from_job_id(self, job_id_list: list[str]) -> JobIdAnnofabProjectIdDict:
         job_id_dict = {
-            job["job_id"]: get_annofab_project_id_from_job(job)
-            for job in self.all_job_list
-            if get_annofab_project_id_from_job(job) is not None
+            job["job_id"]: get_annofab_project_id_from_job(job) for job in self.all_job_list if get_annofab_project_id_from_job(job) is not None
         }
 
         result = {}
@@ -99,7 +96,7 @@ class ListLabor:
 
         return result
 
-    def get_user_id_annofab_account_id_dict(self, user_id_set) -> dict[str, str]:
+    def get_user_id_annofab_account_id_dict(self, user_id_set) -> dict[str, str]:  # noqa: ANN001
         result = {}
         for user_id in user_id_set:
             annofab_account_id = self.annowork_service.wrapper.get_annofab_account_id_from_user_id(user_id)
@@ -126,28 +123,26 @@ class ListLabor:
             )
 
         elif annofab_project_id_list is not None:
-            job_id_annofab_project_id_dict = self.get_job_id_annofab_project_id_dict_from_annofab_project_id(
-                annofab_project_id_list
-            )
+            job_id_annofab_project_id_dict = self.get_job_id_annofab_project_id_dict_from_annofab_project_id(annofab_project_id_list)
             actual_working_time_list = self.list_actual_working_time_obj.get_actual_working_times(
                 job_ids=job_id_annofab_project_id_dict.keys(),
                 start_date=start_date,
                 end_date=end_date,
                 is_set_additional_info=True,
             )
+        else:
+            raise RuntimeError("`job_id_list`と`annofab_project_id_list`の両方がNoneです。")
 
         if len(actual_working_time_list) == 0:
             return []
 
         # annofabのデータは日本時間に固定されているので、日本時間を指定する
-        daily_list = create_actual_working_hours_daily_list(
-            actual_working_time_list, timezone_offset_hours=TIMEZONE_OFFSET_HOURS
-        )
+        daily_list = create_actual_working_hours_daily_list(actual_working_time_list, timezone_offset_hours=TIMEZONE_OFFSET_HOURS)
 
         user_id_set = {elm.user_id for elm in daily_list}
         user_id_annofab_account_id_dict = self.get_user_id_annofab_account_id_dict(user_id_set)
         if len(user_id_set) != len(user_id_annofab_account_id_dict):
-            raise RuntimeError(f"アカウント外部連携情報にAnnofabのaccount_idが設定されていないユーザがいます。")
+            raise RuntimeError("アカウント外部連携情報にAnnofabのaccount_idが設定されていないユーザがいます。")
 
         result = []
         for elm in daily_list:
@@ -168,7 +163,24 @@ class ListLabor:
         return result
 
 
-def visualize_statistics(temp_dir: Path, args):
+def mask_credential_in_command(command: list[str]) -> list[str]:
+    """
+    コマンドのリストに含まれている認証情報を、`***`に置き換えてマスクします。
+
+    Args:
+        command: 実行するコマンドのリスト（変更されません）
+    """
+    tmp_command = copy.deepcopy(command)
+    for masked_option in ["--annofab_user_id", "--annofab_password", "--mfa_code"]:
+        try:
+            index = tmp_command.index(masked_option)
+            tmp_command[index + 1] = "***"
+        except ValueError:
+            continue
+    return tmp_command
+
+
+def visualize_statistics(temp_dir: Path, args):  # noqa: ANN001, ANN201
     annowork_service = build_annoworkapi(args)
     job_id_list = get_list_from_args(args.job_id)
     annofab_project_id_list = get_list_from_args(args.annofab_project_id)
@@ -196,13 +208,13 @@ def visualize_statistics(temp_dir: Path, args):
     ]
 
     if annofab_project_id_list is not None:
-        command.extend(["--project_id"] + annofab_project_id_list)
+        command.extend(["--project_id"] + annofab_project_id_list)  # noqa: RUF005
     elif job_id_list is not None:
         job_id_annofab_project_id_dict = main_obj.get_job_id_annofab_project_id_dict_from_job_id(job_id_list)
         if len(job_id_annofab_project_id_dict) == 0:
-            logger.error(f"Annofabプロジェクトに紐づくジョブが0件なので、終了します。")
+            logger.error("Annofabプロジェクトに紐づくジョブが0件なので、終了します。")
             return
-        command.extend(["--project_id"] + list(job_id_annofab_project_id_dict.values()))
+        command.extend(["--project_id"] + list(job_id_annofab_project_id_dict.values()))  # noqa: RUF005
 
     if args.start_date is not None:
         command.extend(["--start_date", args.start_date])
@@ -216,15 +228,21 @@ def visualize_statistics(temp_dir: Path, args):
     if args.annofab_mfa_code is not None:
         command.extend(["--mfa_code", str(args.annofab_mfa_code)])
 
+    if args.annofab_user_id is not None:
+        command.extend(["--annofab_user_id", str(args.annofab_user_id)])
+
+    if args.annofab_password is not None:
+        command.extend(["--annofab_password", str(args.annofab_password)])
+
     if args.annofabcli_options is not None:
         command.extend(args.annofabcli_options)
 
-    str_command = " ".join(command)
+    str_command = " ".join(mask_credential_in_command(command))
     logger.debug(f"run command: {str_command}")
     subprocess.run(command, check=True)
 
 
-def main(args):
+def main(args):  # noqa: ANN001, ANN201
     if args.temp_dir is not None:
         visualize_statistics(args.temp_dir, args)
     else:
@@ -232,7 +250,7 @@ def main(args):
             visualize_statistics(Path(str_temp_dir), args)
 
 
-def parse_args(parser: argparse.ArgumentParser):
+def parse_args(parser: argparse.ArgumentParser):  # noqa: ANN201
     parser.add_argument(
         "-w",
         "--workspace_id",
@@ -253,6 +271,8 @@ def parse_args(parser: argparse.ArgumentParser):
     parser.add_argument("--temp_dir", type=Path, required=False, help="テンポラリディレクトリ")
 
     parser.add_argument("--annofab_mfa_code", type=str, help="Annofabにログインする際のMFAコード")
+    parser.add_argument("--annofab_user_id", type=str, help="Annofabにログインする際のユーザID")
+    parser.add_argument("--annofab_password", type=str, help="Annofabにログインする際のパスワード")
 
     # 残りの引数は `annofabcli statistics visualize`コマンドにそのまま渡す
     parser.add_argument(
