@@ -1,5 +1,3 @@
-from __future__ import annotations
-
 import argparse
 import logging
 import sys
@@ -17,12 +15,10 @@ logger = logging.getLogger(__name__)
 
 
 class ListExpectedWorkingTime:
-    def __init__(self, annowork_service: AnnoworkResource, workspace_id: str):
+    def __init__(self, annowork_service: AnnoworkResource, workspace_id: str):  # noqa: ANN204
         self.annowork_service = annowork_service
         self.workspace_id = workspace_id
-        self.workspace_members = self.annowork_service.api.get_workspace_members(
-            self.workspace_id, query_params={"includes_inactive_members": True}
-        )
+        self.workspace_members = self.annowork_service.api.get_workspace_members(self.workspace_id, query_params={"includes_inactive_members": True})
 
     def get_expected_working_times_by_user_id(
         self, user_id_list: list[str], *, start_date: Optional[str] = None, end_date: Optional[str] = None
@@ -64,7 +60,7 @@ class ListExpectedWorkingTime:
         logger.debug(f"予定稼働時間情報を取得します。{query_params=}")
         return self.annowork_service.api.get_expected_working_times(self.workspace_id, query_params=query_params)
 
-    def set_member_info_to_working_times(self, working_times: list[dict[str, Any]]):
+    def set_member_info_to_working_times(self, working_times: list[dict[str, Any]]):  # noqa: ANN201
         workspace_member_dict = {e["workspace_member_id"]: e for e in self.workspace_members}
         for elm in working_times:
             workspace_member_id = elm["workspace_member_id"]
@@ -80,7 +76,7 @@ class ListExpectedWorkingTime:
                 }
             )
 
-    def main(
+    def main(  # noqa: ANN201
         self,
         *,
         output: Path,
@@ -90,16 +86,14 @@ class ListExpectedWorkingTime:
         end_date: Optional[str] = None,
     ):
         if user_id_list is not None:
-            result = self.get_expected_working_times_by_user_id(
-                user_id_list=user_id_list, start_date=start_date, end_date=end_date
-            )
+            result = self.get_expected_working_times_by_user_id(user_id_list=user_id_list, start_date=start_date, end_date=end_date)
         else:
             result = self.get_expected_working_times(start_date=start_date, end_date=end_date)
 
         self.set_member_info_to_working_times(result)
 
         if len(result) == 0:
-            logger.warning(f"予定稼働時間情報0件なので、出力しません。")
+            logger.warning("予定稼働時間情報0件なので、出力しません。")
             return
 
         logger.info(f"{len(result)} 件の予定稼働時間情報を出力します。")
@@ -122,7 +116,7 @@ class ListExpectedWorkingTime:
             print_csv(df[columns], output=output)
 
 
-def main(args):
+def main(args):  # noqa: ANN001, ANN201
     annowork_service = build_annoworkapi(args)
     user_id_list = get_list_from_args(args.user_id)
     start_date: Optional[str] = args.start_date
@@ -130,7 +124,7 @@ def main(args):
 
     command = " ".join(sys.argv[0:3])
     if all(v is None for v in [user_id_list, start_date, end_date]):
-        print(f"{command}: error: '--start_date'や'--user_id'などの絞り込み条件を1つ以上指定してください。", file=sys.stderr)
+        print(f"{command}: error: '--start_date'や'--user_id'などの絞り込み条件を1つ以上指定してください。", file=sys.stderr)  # noqa: T201
         sys.exit(COMMAND_LINE_ERROR_STATUS_CODE)
 
     ListExpectedWorkingTime(annowork_service=annowork_service, workspace_id=args.workspace_id).main(
@@ -142,7 +136,7 @@ def main(args):
     )
 
 
-def parse_args(parser: argparse.ArgumentParser):
+def parse_args(parser: argparse.ArgumentParser):  # noqa: ANN201
     parser.add_argument(
         "-w",
         "--workspace_id",
@@ -173,8 +167,6 @@ def add_parser(subparsers: Optional[argparse._SubParsersAction] = None) -> argpa
     subcommand_name = "list"
     subcommand_help = "予定稼働時間の一覧を出力します。"
 
-    parser = annoworkcli.common.cli.add_parser(
-        subparsers, subcommand_name, subcommand_help, description=subcommand_help
-    )
+    parser = annoworkcli.common.cli.add_parser(subparsers, subcommand_name, subcommand_help, description=subcommand_help)
     parse_args(parser)
     return parser
